@@ -4,14 +4,14 @@
 # Script, Category, Subcategory, value, referenceGlyph, filter
 
 # Letters
-*,Letter,Uppercase,1.25,H,*,
+*,Letter,Uppercase,1.15,H,*,
 *,Letter,Smallcaps,1.1,h.sc,*,
 *,Letter,Lowercase,1,x,*,
 *,Letter,Lowercase,0.7,m.sups,.sups,
 
 # Numbers
-*,Number,Decimal Digit,1.2,one,*,
-*,Number,Decimal Digit,1.2,zero.osf,.osf,
+*,Number,Decimal Digit,1.1,one,*,
+*,Number,Decimal Digit,1.1,zero.osf,.osf,
 *,Number,Fraction,1.3,*,*,
 *,Number,*,1.0,*,.dnom,
 *,Number,*,1.0,*,.numr,
@@ -20,9 +20,12 @@
 
 # Punctuation
 *,Punctuation,Other,1,*,*,
+*,Punctuation,Other,1.1,*,exclam,
+*,Punctuation,Other,0.9,*,period,
 *,Punctuation,Parenthesis,1.2,*,*,
 *,Punctuation,Quote,1.2,*,*,
-*,Punctuation,Dash,1,*,*,
+*,Punctuation,Quote,1,*,quote,
+*,Punctuation,Dash,0.8,*,*,
 *,Punctuation,*,1,*,slash,
 *,Punctuation,*,1.2,*,*,
 
